==> Dressing_1.0.0.202512151442-1208.jar: src/dressing/ui/project/FloorConfigWizardFormPage.java <==
package dressing.ui.project;

import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;

import org.eclipse.jface.wizard.IWizardPage;
import org.eclipse.jface.wizard.WizardPage;
import org.eclipse.swt.SWT;
import org.eclipse.swt.widgets.Composite;

import com.badlogic.gdx.math.Vector3;

import dressing.model.ModelProvider;
import dressing.model.ProjectManager;
import dressing.ui.engine3d.SceneTexture.CATEGORY;
import dressing.ui.shapedrawer.FinalPage;
import gdxapp.object3d.GeometryObject;
import geometry.CompoundObject;

public class FloorConfigWizardFormPage extends WizardPage implements PropertyChangeListener , FinalPage {
	
	

	private GeometricObjectSettingComposite composite;
	
	GeometryObject worldobject;
	
	protected FloorConfigWizardFormPage(String pageName) {
		super(pageName);
	}
	
	public GeometricObjectSettingComposite getComposite() {
		return composite;
	}

	public void setComposite(GeometricObjectSettingComposite composite) {
		this.composite = composite;
	}

	protected FloorConfigWizardFormPage(CompoundObject geometry) {
		super("");
		setTitle("Création du socle");
		this.worldobject = new GeometryObject();
		geometry.getBorder().setMaterial(ProjectManager.getManager().getCurrentScene().getPreferences().getFloorMtl());
		this.worldobject.setGeometry(geometry);
		this.worldobject.setRealWorldDimension(geometry.getRealWorldDimension(0.01f));
		this.worldobject.setRealWorldPosition(new Vector3(0, 0.005f,0));
		this.worldobject.addPropertyChangeListener(this);
		this.worldobject.setUserData("FLOOR");
		
	}

	@Override
	public void createControl(Composite parent) {
		composite = new GeometricObjectSettingComposite(parent, SWT.EMBEDDED,(GeometryObject) worldobject,ModelProvider.getMaterialsByCategory(CATEGORY.FLOOR));
		composite.addPropertyChangeListener((event) -> {
			getWizard().getContainer().updateButtons();
		});
		setControl(composite);

	}
	public void clearlistners() {
		worldobject.removePropertyChangeListener(this);
	}

	@Override
	public boolean isPageComplete() {
		return composite.hasValidInput();
		
	}

	@Override
	public void propertyChange(PropertyChangeEvent evt) {
		if(isCurrentPage())
		{
			if (FloorConfigWizardFormPage.this != null) {
				setPageComplete(isPageComplete());
				if (getWizard().getContainer() != null)
					getContainer().updateButtons();
			}
		}
	}

	@Override
	public void onHide() {
		composite.apply();
		clearlistners();	
		ProjectManager.getManager().getCurrentScene().addActor(worldobject, true);
	}

	@Override
	public IWizardPage getNextPage() {
		return null;
	}

	@Override
	public IWizardPage getPreviousPage() {
		if(getWizard() == null)
			return null;
		return getWizard().getStartingPage();
	}
	

}

==> Dressing_1.0.0.202512261618-1211.jar: src/dressing/ui/project/FloorConfigWizardFormPage.java <==
package dressing.ui.project;

import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;

import org.eclipse.jface.wizard.IWizardPage;
import org.eclipse.jface.wizard.WizardPage;
import org.eclipse.swt.SWT;
import org.eclipse.swt.widgets.Composite;

import com.badlogic.gdx.math.Vector3;

import dressing.model.ModelProvider;
import dressing.model.ProjectManager;
import dressing.ui.engine3d.SceneTexture.CATEGORY;
import dressing.ui.shapedrawer.FinalPage;
import gdxapp.object3d.GeometryObject;
import geometry.CompoundObject;

public class FloorConfigWizardFormPage extends WizardPage implements PropertyChangeListener , FinalPage {
	
	

	private GeometricObjectSettingComposite composite;
	
	GeometryObject worldobject;
	
	protected FloorConfigWizardFormPage(String pageName) {
		super(pageName);
	}
	
	public GeometricObjectSettingComposite getComposite() {
		return composite;
	}

	public void setComposite(GeometricObjectSettingComposite composite) {
		this.composite = composite;
	}

	protected FloorConfigWizardFormPage(CompoundObject geometry) {
		super("");
		setTitle("Création du socle");
		this.worldobject = new GeometryObject();
		geometry.getBorder().setMaterial(ProjectManager.getManager().getCurrentScene().getPreferences().getFloorMtl());
		this.worldobject.setGeometry(geometry);
		Vector3 size = new Vector3();
		Vector3 position = new Vector3();
		geometry.calculateBounds(0.01f, size, position);
		this.worldobject.setRealWorldDimension(size);
		this.worldobject.setRealWorldPosition(position);
		this.worldobject.addPropertyChangeListener(this);
		this.worldobject.setUserData("FLOOR");
		
	}

	@Override
	public void createControl(Composite parent) {
		composite = new GeometricObjectSettingComposite(parent, SWT.EMBEDDED,(GeometryObject) worldobject,ModelProvider.getMaterialsByCategory(CATEGORY.FLOOR));
		composite.addPropertyChangeListener((event) -> {
			getWizard().getContainer().updateButtons();
		});
		setControl(composite);

	}
	public void clearlistners() {
		worldobject.removePropertyChangeListener(this);
	}

	@Override
	public boolean isPageComplete() {
		return composite.hasValidInput();
		
	}

	@Override
	public void propertyChange(PropertyChangeEvent evt) {
		if(isCurrentPage())
		{
			if (FloorConfigWizardFormPage.this != null) {
				setPageComplete(isPageComplete());
				if (getWizard().getContainer() != null)
					getContainer().updateButtons();
			}
		}
	}

	@Override
	public void onHide() {
		composite.apply();
		clearlistners();	
		ProjectManager.getManager().getCurrentScene().addActor(worldobject, true);
	}

	@Override
	public IWizardPage getNextPage() {
		return null;
	}

	@Override
	public IWizardPage getPreviousPage() {
		if(getWizard() == null)
			return null;
		return getWizard().getStartingPage();
	}
	

}
